pub struct TxCreateTokenWithFreezeAuthMetadataParams {
pub payer: Pubkey,
pub mint: Pubkey,
pub initial_mint_authority: Pubkey,
pub freeze_authority: Pubkey,
pub decimals: u8,
pub name: String,
pub symbol: String,
pub image: String,
pub description: String,
pub immutable: bool,
}Expand description
Parameters for freeze-authority metadata creation flow.
Fields
payer: PubkeyPayer that funds the mint account and metadata PDA
mint: PubkeyMint account public key
Initial mint authority that will be cleared to None before create_metadata
Freeze authority who will sign create_metadata
decimals: u8Number of decimals for the mint
name: StringMetadata fields
symbol: Stringimage: Stringdescription: Stringimmutable: boolTrait Implementations
Sourceimpl Clone for TxCreateTokenWithFreezeAuthMetadataParams
impl Clone for TxCreateTokenWithFreezeAuthMetadataParams
Sourcefn clone(&self) -> TxCreateTokenWithFreezeAuthMetadataParams
fn clone(&self) -> TxCreateTokenWithFreezeAuthMetadataParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TxCreateTokenWithFreezeAuthMetadataParams
impl RefUnwindSafe for TxCreateTokenWithFreezeAuthMetadataParams
impl Send for TxCreateTokenWithFreezeAuthMetadataParams
impl Sync for TxCreateTokenWithFreezeAuthMetadataParams
impl Unpin for TxCreateTokenWithFreezeAuthMetadataParams
impl UnwindSafe for TxCreateTokenWithFreezeAuthMetadataParams